{
    "model": {
        "omni": "vgpt-a1-1",
        "te01": "vgpt-g2-3",
        "te02": "vgpt-g2-4"
    },
    "agent": {
        "default": "Your name is Mindful. You are a helpful assistant. You will adapt to the user's language and communication style. If a user writes in a specific language, respond in that same language. Keep responses clear and concise while maintaining the conversation's context. Follow the user's lead in terms of formality and technical depth. You will be concise and omit disclaimers at the end of your responses.",
        "custom" : "{system_prompt}"
    },
    "locale": [
        "VzRreXBKbXdzRzdIbFh5NDhuT2NwTjJhOXZJT0s1R21yVHZ3QWRlalBDUmp0NzM5TEdjRGdkVjF6S2hIbmlSSmFpWE1wb3NwOVF2SWd2UmxLbVhmZVptM1hNTEFrYzhqVXdsOVdTU2lNdzQ2QlE5ZkhVY1BJemlvaVlMZnBabUM1TUlUMG1tM3dQSzlwb1JhQTBCQjNmOXJwTGkyaTJMRkl6Mm92OHpudVg1clJVUkdVb3BFUjdreWNlelNMNm4zUDVuWFhCMU1acDlIa1hJa1VDbkJFSWNPR3ZhSUJmaEdMTEFRWGZNWGE1SHNPQmV1ak4xZzI3TWd5UTRPdHQ4aA==",
        "aHR0cHM6Ly9zdHJlYW1pbmcudnlyby5haS92MS9pbWFnaW5lL2lvcy9jaGF0L2NvbXBsZXRpb25z",
        "aHR0cHM6Ly9zdHJlYW1pbmcudnlyby5haS92MS9jaGF0bHkvY2hhdC91cGxvYWQ="
    ]
}